/*
 * NIST HL7 WebService
 * TestMPVJaxWS.java June 18, 2007
 *
 * This code was produced by the National Institute of Standards and
 * Technology (NIST). See the "nist.disclaimer" file given in the distribution 
 * for information on the use and redistribution of this software.
 */
package main;

import gov.nist.hl7.ws.validation.messagevalidation.*;

import java.io.FileInputStream;
import java.net.URL;

import javax.xml.namespace.QName;
import javax.xml.ws.BindingProvider;

/**
 * @author Roch Bertucat (NIST)
 * This class is a basic JAX-WS-implemented client to use 
 * with the NIST validation module web service hosted on http://xreg2.nist.gov:8080/axis2/services/
 */
public class TestMPVJaxWS {

    /**
     * @param args
     */
    public static void main(String[] args) {
        try {
            // Transform Files to string
            FileInputStream fis = new FileInputStream("files/message/ValidProfileForMessageValidation.xml");
            byte b[]= new byte[fis.available()];
            fis.read(b);
            String profile = new String(b);
            
            fis = new FileInputStream("files/message/IncorrectEVN.1.MSH.9.MSG.2.xml");
            //fis = new FileInputStream("files/message/ValidProfileForMessageValidation.msg00001.xml");
            b = new byte[fis.available()];
            fis.read(b);
            String message = new String(b);

            fis = new FileInputStream("files/context/MessageValidationContext.xml");
            b = new byte[fis.available()];
            fis.read(b);
            String messageValidContext = new String(b);
            fis.close();
            
            // Create the connector
            // Local information      
//          QName name = new QName ("http://messagevalidation.validation.ws.hl7.nist.gov", "MessageValidation");
//          MessageValidation pv = new MessageValidation(new URL ("http://localhost:8080/axis2/services/MessageValidation"), name);            
            // Create the connector to the WebService
            QName name = new QName ("http://messagevalidation.validation.ws.hl7.nist.gov", "MessageValidation");
            MessageValidation mv = new MessageValidation(new URL ("http://xreg2.nist.gov:8080/axis2/services/MessageValidation"), name);
            MessageValidationPortType mvpt = mv.getMessageValidationSOAP11Port();  
          
            // To allow Session Management
            ((BindingProvider)mvpt).getRequestContext().put(BindingProvider.SESSION_MAINTAIN_PROPERTY,true);
            
            // Set files on the WS
            boolean respProfile = mvpt.setProfile(profile, "BadMsgTypeEventTypeCombination");
            boolean respMessage = mvpt.setMessage(message, true);
            boolean respContext = mvpt.setMessageValidationContext(messageValidContext);
            String respError = mvpt.getLastExceptionMessage();
            System.out.println(respError);
            
            // Call the validation method
            if (respProfile && respMessage) {
                boolean vr = mvpt.validate();
                if (vr) 
                    System.out.println ("Message Valid");
                else 
                    System.out.println ("Message Not Valid");
            }
            
            respError = mvpt.getLastExceptionMessage();
            System.out.println(respError);
            
            // Display the validation report
            String reportResponse = mvpt.getMessageValidationReport();
            System.out.println(reportResponse);
            
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
