/*
 * NIST HL7 WebService
 * TestPVJaxWS.java June 18, 2007
 *
 * This code was produced by the National Institute of Standards and
 * Technology (NIST). See the "nist.disclaimer" file given in the distribution 
 * for information on the use and redistribution of this software.
 */
package main;

import gov.nist.hl7.ws.validation.profilevalidation.*;

import java.io.FileInputStream;
import java.net.URL;

import javax.xml.namespace.QName;
import javax.xml.ws.BindingProvider;

/**
 * @author Roch Bertucat (NIST)
 * This class is a basic JAX-WS-implemented client to use 
 * with the NIST validation module web service hosted on http://xreg2.nist.gov:8080/axis2/services/
 */
public class TestPVJaxWS {

    /**
     * @param args
     */
    public static void main(String[] args) {
        try {
            // Transform Files to string
            FileInputStream fis = new FileInputStream("files/profile/BadMsgTypeEventTypeCombination.xml");
            byte b[]= new byte[fis.available()];
            fis.read(b);
            String profile = new String(b);

            fis = new FileInputStream("files/context/ProfileValidationContext.xml");
            b = new byte[fis.available()];
            fis.read(b);
            String profValidContext = new String(b);
            fis.close();
            
            // Create the connector
            // Local information      
//          QName name = new QName ("http://profilevalidation.validation.ws.hl7.nist.gov", "ProfileValidation");
//          ProfileValidation pv = new ProfileValidation(new URL ("http://localhost:8080/axis2/services/ProfileValidation"), name);            
            // Create the connector to the WebService
            QName name = new QName ("http://profilevalidation.validation.ws.hl7.nist.gov", "ProfileValidation");
            ProfileValidation pv = new ProfileValidation(new URL ("http://xreg2.nist.gov:8080/axis2/services/ProfileValidation"), name);
            ProfileValidationPortType pvpt = pv.getProfileValidationSOAP11Port();  
          
            // To allow Session Management
            ((BindingProvider)pvpt).getRequestContext().put(BindingProvider.SESSION_MAINTAIN_PROPERTY,true);
            
            // Set files on the WS
            boolean respProfile = pvpt.setProfile(profile, "BadMsgTypeEventTypeCombination");
            boolean respContext = pvpt.setProfileValidationContext(profValidContext);
            String respError = pvpt.getLastExceptionMessage();
            System.out.println(respError);
            
            // Call the validation method
            if (respProfile) {
                boolean vr = pvpt.validate();
                if (vr) 
                    System.out.println ("Profile Valid");
                else 
                    System.out.println ("Profile Not Valid");
            }
            
            respError = pvpt.getLastExceptionMessage();
            System.out.println(respError);
            
            // Display the validation report
            String reportResponse = pvpt.getProfileValidationReport();
            System.out.println(reportResponse);
            
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
